pub struct Notifications(/* private fields */);Expand description
Change notifications that a controller client can register.
Implementations
Sourceimpl Notifications
impl Notifications
Sourcepub const PLAYBACK_STATUS: Notifications
pub const PLAYBACK_STATUS: Notifications
AVRCP EVENT_PLAYBACK_STATUS_CHANGED Notification
Sourcepub const TRACK: Notifications
pub const TRACK: Notifications
AVRCP EVENT_TRACK_CHANGED Notification
Sourcepub const TRACK_POS: Notifications
pub const TRACK_POS: Notifications
AVRCP EVENT_TRACK_POS_CHANGED Notification
Sourcepub const BATT_STATUS: Notifications
pub const BATT_STATUS: Notifications
AVRCP EVENT_BATT_STATUS_CHANGED Notification
Sourcepub const SYSTEM_STATUS: Notifications
pub const SYSTEM_STATUS: Notifications
AVRCP EVENT_SYSTEM_STATUS_CHANGED Notification
Sourcepub const PLAYER_APPLICATION_SETTINGS: Notifications
pub const PLAYER_APPLICATION_SETTINGS: Notifications
AVRCP EVENT_PLAYER_APPLICATION_SETTINGS_CHANGED Notification
Sourcepub const ADDRESSED_PLAYER: Notifications
pub const ADDRESSED_PLAYER: Notifications
AVRCP EVENT_ADDRESSED_PLAYER_CHANGED Notification
Sourcepub const VOLUME: Notifications
pub const VOLUME: Notifications
AVRCP EVENT_VOLUME_CHANGED Notification
Sourcepub const AVAILABLE_PLAYERS: Notifications
pub const AVAILABLE_PLAYERS: Notifications
AVRCP EVENT_AVAILABLE_PLAYERS_CHANGED Notification
Sourcepub const CONNECTION: Notifications
pub const CONNECTION: Notifications
Internal connection change event.
Sourceimpl Notifications
impl Notifications
Sourcepub const fn empty() -> Notifications
pub const fn empty() -> Notifications
Get a flags value with all bits unset.
Sourcepub const fn all() -> Notifications
pub const fn all() -> Notifications
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Notifications>
pub const fn from_bits(bits: u32) -> Option<Notifications>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Notifications
pub const fn from_bits_truncate(bits: u32) -> Notifications
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Notifications
pub const fn from_bits_retain(bits: u32) -> Notifications
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Notifications>
pub fn from_name(name: &str) -> Option<Notifications>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Notifications) -> bool
pub const fn intersects(&self, other: Notifications) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Notifications) -> bool
pub const fn contains(&self, other: Notifications) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Notifications)
pub fn insert(&mut self, other: Notifications)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: Notifications)
pub fn remove(&mut self, other: Notifications)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Notifications)
pub fn toggle(&mut self, other: Notifications)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Notifications, value: bool)
pub fn set(&mut self, other: Notifications, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Notifications) -> Notifications
pub const fn intersection(self, other: Notifications) -> Notifications
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Notifications) -> Notifications
pub const fn union(self, other: Notifications) -> Notifications
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Notifications) -> Notifications
pub const fn difference(self, other: Notifications) -> Notifications
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Notifications) -> Notifications
pub const fn symmetric_difference(self, other: Notifications) -> Notifications
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Notifications
pub const fn complement(self) -> Notifications
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Notifications
impl Notifications
Sourcepub const fn iter(&self) -> Iter<Notifications> ⓘ
pub const fn iter(&self) -> Iter<Notifications> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Notifications> ⓘ
pub const fn iter_names(&self) -> IterNames<Notifications> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.