pub struct PlayerFeatureBits(/* private fields */);Implementations
Sourceimpl PlayerFeatureBits
impl PlayerFeatureBits
pub const SELECT: PlayerFeatureBits
pub const UP: PlayerFeatureBits
pub const DOWN: PlayerFeatureBits
pub const LEFT: PlayerFeatureBits
pub const RIGHT: PlayerFeatureBits
pub const RIGHT_UP: PlayerFeatureBits
pub const RIGHT_DOWN: PlayerFeatureBits
pub const LEFT_UP: PlayerFeatureBits
pub const LEFT_DOWN: PlayerFeatureBits
pub const ROOT_MENU: PlayerFeatureBits
pub const SETUP_MENU: PlayerFeatureBits
pub const CONTENTS_MENU: PlayerFeatureBits
pub const FAVORITE_MENU: PlayerFeatureBits
pub const EXIT: PlayerFeatureBits
pub const ZERO: PlayerFeatureBits
pub const ONE: PlayerFeatureBits
pub const TWO: PlayerFeatureBits
pub const THREE: PlayerFeatureBits
pub const FOUR: PlayerFeatureBits
pub const FIVE: PlayerFeatureBits
pub const SIX: PlayerFeatureBits
pub const SEVEN: PlayerFeatureBits
pub const EIGHT: PlayerFeatureBits
pub const NINE: PlayerFeatureBits
pub const DOT: PlayerFeatureBits
pub const ENTER: PlayerFeatureBits
pub const CLEAR: PlayerFeatureBits
pub const CHANNEL_UP: PlayerFeatureBits
pub const CHANNEL_DOWN: PlayerFeatureBits
pub const PREVIOUS_CHANNEL: PlayerFeatureBits
pub const SOUND_SELECT: PlayerFeatureBits
pub const INPUT_SELECT: PlayerFeatureBits
pub const DISPLAY_INFORMATION: PlayerFeatureBits
pub const HELP: PlayerFeatureBits
pub const PAGE_UP: PlayerFeatureBits
pub const PAGE_DOWN: PlayerFeatureBits
pub const POWER: PlayerFeatureBits
pub const VOLUME_UP: PlayerFeatureBits
pub const VOLUME_DOWN: PlayerFeatureBits
pub const MUTE: PlayerFeatureBits
pub const PLAY: PlayerFeatureBits
pub const STOP: PlayerFeatureBits
pub const PAUSE: PlayerFeatureBits
pub const RECORD: PlayerFeatureBits
pub const REWIND: PlayerFeatureBits
pub const FAST_FORWARD: PlayerFeatureBits
pub const EJECT: PlayerFeatureBits
pub const FORWARD: PlayerFeatureBits
pub const BACKWARD: PlayerFeatureBits
pub const ANGLE: PlayerFeatureBits
pub const SUBPICTURE: PlayerFeatureBits
pub const F1: PlayerFeatureBits
pub const F2: PlayerFeatureBits
pub const F3: PlayerFeatureBits
pub const F4: PlayerFeatureBits
pub const F5: PlayerFeatureBits
pub const VENDOR_UNIQUE: PlayerFeatureBits
pub const BASIC_GROUP_NAVIGATION: PlayerFeatureBits
pub const ADVANCED_CONTROL_PLAYER: PlayerFeatureBits
pub const BROWSING: PlayerFeatureBits
pub const SEARCHING: PlayerFeatureBits
pub const ADD_TO_NOW_PLAYING: PlayerFeatureBits
pub const UIDS_UNIQUE_IN_PLAYER_BROWSE_TREE: PlayerFeatureBits
pub const ONLY_BROWSABLE_WHEN_ADDRESSED: PlayerFeatureBits
Sourceimpl PlayerFeatureBits
impl PlayerFeatureBits
Sourcepub const fn empty() -> PlayerFeatureBits
pub const fn empty() -> PlayerFeatureBits
Get a flags value with all bits unset.
Sourcepub const fn all() -> PlayerFeatureBits
pub const fn all() -> PlayerFeatureBits
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<PlayerFeatureBits>
pub const fn from_bits(bits: u64) -> Option<PlayerFeatureBits>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> PlayerFeatureBits
pub const fn from_bits_truncate(bits: u64) -> PlayerFeatureBits
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> PlayerFeatureBits
pub const fn from_bits_retain(bits: u64) -> PlayerFeatureBits
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<PlayerFeatureBits>
pub fn from_name(name: &str) -> Option<PlayerFeatureBits>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: PlayerFeatureBits) -> bool
pub const fn intersects(&self, other: PlayerFeatureBits) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: PlayerFeatureBits) -> bool
pub const fn contains(&self, other: PlayerFeatureBits) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: PlayerFeatureBits)
pub fn insert(&mut self, other: PlayerFeatureBits)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: PlayerFeatureBits)
pub fn remove(&mut self, other: PlayerFeatureBits)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: PlayerFeatureBits)
pub fn toggle(&mut self, other: PlayerFeatureBits)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: PlayerFeatureBits, value: bool)
pub fn set(&mut self, other: PlayerFeatureBits, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: PlayerFeatureBits) -> PlayerFeatureBits
pub const fn intersection(self, other: PlayerFeatureBits) -> PlayerFeatureBits
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: PlayerFeatureBits) -> PlayerFeatureBits
pub const fn union(self, other: PlayerFeatureBits) -> PlayerFeatureBits
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: PlayerFeatureBits) -> PlayerFeatureBits
pub const fn difference(self, other: PlayerFeatureBits) -> PlayerFeatureBits
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: PlayerFeatureBits,
) -> PlayerFeatureBits
pub const fn symmetric_difference( self, other: PlayerFeatureBits, ) -> PlayerFeatureBits
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> PlayerFeatureBits
pub const fn complement(self) -> PlayerFeatureBits
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PlayerFeatureBits
impl PlayerFeatureBits
Sourcepub const fn iter(&self) -> Iter<PlayerFeatureBits> ⓘ
pub const fn iter(&self) -> Iter<PlayerFeatureBits> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PlayerFeatureBits> ⓘ
pub const fn iter_names(&self) -> IterNames<PlayerFeatureBits> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.